==> wowit-0.4.22.tar.gz: lib/controllers/connect_controller.dart <==
import 'package:flutter/foundation.dart';
import 'package:get/get.dart';
import 'dart:io';
import 'package:flutter/material.dart';
import 'package:wowit/controllers/base_controller.dart';
import 'package:wowit/common.dart';
import 'dart:async';
import 'package:wowit/firebase_service.dart';
import 'package:connectivity/connectivity.dart';
import 'package:wowit/message.dart';

class WidgetConnectivity extends StatefulWidget {
  const WidgetConnectivity({
    super.key,
    required this.baseController,
  });

  final BaseController baseController;

  @override
  State<StatefulWidget> createState() => _WidgetConnectivity();
}

class _WidgetConnectivity extends State<WidgetConnectivity> {
  Map mapSource = {
    ConnectivityResult.none: false,
  };
  final MyConnectivity _connectivity = MyConnectivity.instance;

  @override
  Widget build(BuildContext context) {
    return GetBuilder(
      init: widget.baseController,
      builder: (BaseController controller) {
        return SizedBox(
          height: controller.isOnline ? 0 : 20,
          child: Container(
            color: const Color(0xff103C61),
            width: MediaQuery.of(context).size.width,
            child: Center(
              child: Text(
                Message.getMessage('NO_INTERNET_CONNECTION'),
                style: const TextStyle(
                  color: Colors.white,
                  fontSize: 10,
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  @override
  void dispose() {
    _connectivity.disposeStream();
    super.dispose();
  }
}

class MyConnectivity {
  MyConnectivity._internal();

  static final MyConnectivity _instance = MyConnectivity._internal();

  static MyConnectivity get instance => _instance;

  bool _isOnline = false;
  bool get isOnline => _isOnline;

  Connectivity connectivity = Connectivity();

  StreamController controller = StreamController.broadcast();

  Stream get myStream => controller.stream;

  void initialise(BaseController baseController) async {
    var result = await connectivity.checkConnectivity();
    _checkStatus(result, baseController);
    connectivity.onConnectivityChanged.listen((connectivityResult) {
      _checkStatus(connectivityResult, baseController);
    });
  }

  void _checkStatus(ConnectivityResult connectivityResult,
      BaseController baseController) async {
    bool isOnline = false;
    try {
      final result = await InternetAddress.lookup('google.com');
      if (connectivityResult != ConnectivityResult.none &&
          result.isNotEmpty &&
          result[0].rawAddress.isNotEmpty) {
        isOnline = true;
        try {} catch (e) {
          if (kDebugMode) {
            print('Exception _checkStatus: ' + e.toString());
          }
          await FirebaseService.logout();
          await Get.offAll(() => Common.registerScreen);
        } finally {
          //MyApp.hideWatting();
        }
      } else {
        isOnline = false;
      }
    } on SocketException catch (_) {
      isOnline = false;
    }
    if (_isOnline != isOnline) {
      _isOnline = isOnline;
      baseController.update();
    }
  }

  void disposeStream() => controller.close();
}

==> wowit-0.4.27.tar.gz: lib/controllers/connect_controller.dart <==
import 'package:flutter/foundation.dart';
import 'package:get/get.dart';
import 'dart:io';
import 'package:flutter/material.dart';
import 'package:wowit/controllers/base_controller.dart';
import 'package:wowit/common.dart';
import 'dart:async';
import 'package:wowit/firebase_service.dart';
import 'package:connectivity/connectivity.dart';
import 'package:wowit/message.dart';

class WidgetConnectivity extends StatefulWidget {
  const WidgetConnectivity({
    super.key,
    required this.baseController,
  });

  final BaseController baseController;

  @override
  State<StatefulWidget> createState() => _WidgetConnectivity();
}

class _WidgetConnectivity extends State<WidgetConnectivity> {
  Map mapSource = {
    ConnectivityResult.none: false,
  };
  final MyConnectivity _connectivity = MyConnectivity.instance;

  @override
  Widget build(BuildContext context) {
    return GetBuilder(
      init: widget.baseController,
      builder: (BaseController controller) {
        return SizedBox(
          height: controller.isOnline ? 0 : 20,
          child: Container(
            color: const Color(0xff103C61),
            width: MediaQuery.of(context).size.width,
            child: Center(
              child: Text(
                Message.getMessage('NO_INTERNET_CONNECTION'),
                style: const TextStyle(
                  color: Colors.white,
                  fontSize: 10,
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  @override
  void dispose() {
    _connectivity.disposeStream();
    super.dispose();
  }
}

class MyConnectivity {
  MyConnectivity._internal();

  static final MyConnectivity _instance = MyConnectivity._internal();

  static MyConnectivity get instance => _instance;

  bool _isOnline = true;
  bool get isOnline => _isOnline;

  Connectivity connectivity = Connectivity();

  StreamController controller = StreamController.broadcast();

  Stream get myStream => controller.stream;

  void initialise(BaseController baseController) async {
    var result = await connectivity.checkConnectivity();
    _checkStatus(result, baseController);
    connectivity.onConnectivityChanged.listen((connectivityResult) {
      _checkStatus(connectivityResult, baseController);
    });
  }

  void _checkStatus(ConnectivityResult connectivityResult,
      BaseController baseController) async {
    bool isOnline = false;
    try {
      final result = await InternetAddress.lookup('google.com');
      if (connectivityResult != ConnectivityResult.none &&
          result.isNotEmpty &&
          result[0].rawAddress.isNotEmpty) {
        isOnline = true;
        try {} catch (e) {
          if (kDebugMode) {
            print('Exception _checkStatus: ' + e.toString());
          }
          await FirebaseService.logout();
          await Get.offAll(() => Common.registerScreen);
        } finally {
          //MyApp.hideWatting();
        }
      } else {
        isOnline = false;
      }
    } on SocketException catch (_) {
      isOnline = false;
    }
    if (_isOnline != isOnline) {
      _isOnline = isOnline;
      baseController.update();
    }
  }

  void disposeStream() => controller.close();
}
